# Usage

napari leverages the power of Python to enable fast and interactive browsing,
annotation and analysis of large multi-dimensional images.

The tutorials and guides to your left are meant to help you understand how to use
napari, as well as learn about its features and use cases. The
*In-depth explanations* are aimed at those looking for best practices and more
information on how napari works. 

If you are new to napari, check out the [napari quickstart tutorial](tutorials/fundamentals/quick_start).
